#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Twin Share - Environment Manager
"""

# Version information
__version__ = "0.1.26"

# Note: We avoid importing modules here to prevent circular imports
# Modules will be imported as needed by the application
